@@ -1,7 +1,7 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2016-06-04'; # DATE
-our $VERSION = '0.015'; # VERSION
+our $DATE = '2016-06-12'; # DATE
+our $VERSION = '0.016'; # VERSION
 
 use 5.010001;
 use strict;
@@ -117,7 +117,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.015 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-06-04.
+This document describes version 0.016 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2016-06-12.
 
 =head1 SYNOPSIS
 
@@ -148,6 +148,11 @@ converting date from integer (Unix epoch) or
 L<Data::Sah::Coerce::perl::date::str_iso8601> for converting date from ISO8601
 strings like "2016-05-15".
 
+Basically, a coercion rule will provide an expression (C<expr_match>) that
+evaluates to true when data can be coerced, and an expression (C<expr_coerce>)
+to actually coerce/convert data to the target type. This rule can be combined
+with other rules to form the final coercion code.
+
 The module must contain C<meta> subroutine which must return a hashref that has
 the following keys (C<*> marks that the key is required):
 
@@ -166,7 +171,8 @@ certain situations only and can set this key's value to 0.
 To explicitly enable a disabled-by-default rule or explicitly disable an
 enabled-by-default rule, a Sah schema can set the attribute C<x.coerce_rules> or
 C<x.perl.coerce_rules> to something like C<< ["!str_iso8601", "str_alami"] >>
-(this means to exclude the C<str_iso8601> rule but enable the C<str_alami> rule.
+(this means to exclude the C<str_iso8601> rule but enable the C<str_alami>
+rule).
 
 =item * might_die => bool (default: 0)
 
@@ -174,36 +180,37 @@ Whether the rule will generate code that might die (e.g. does not trap failure
 in a conversion process). An example of a rule like this is coercing from string
 in the form of "YYYY-MM-DD" to a DateTime object. The rule might match any
 string in the form of C<< /\A(\d{4})-(\d{2})-(\d{2})\z/ >> and feed it to C<<
-DateTime->new >>, without checking of a valid date, so the latter might die.
+DateTime->new >>, without checking of a valid date, so the DateTime object
+construction might die.
 
 An example of rule that "might not die" is coercing from a comma-separated
 string into array. This process should not die unless under extraordinary
 condition (e.g. out of memory).
 
 For a rule that might die, the program/library that uses the rule module might
-add an eval block around the expr_coerce code that is generated by the rule
-module.
+want to add an eval block around the C<expr_coerce> code that is generated by
+the rule module.
 
 =item * prio => int (0-100, default: 50)
 
 This is to regulate the ordering of rules. The higher the number, the lower the
 priority (meaning the rule will be put further back). Rules that are
-computationally expensive and/or matches more broadly in general should be put
-further back (lower priority, higher number).
+computationally more expensive and/or match more broadly in general should be
+put further back (lower priority, higher number).
 
 =item * precludes => array of (str|re)
 
 List the other rules or rule patterns that are precluded by this rule. Rules
-that are pure alternatives to one another (e.g. date coercien rules
-L<str_alami|Data::Sah::Coerce::date::str_alami> vs
+that are mutually exclusive or pure alternatives to one another (e.g. date
+coercien rules L<str_alami|Data::Sah::Coerce::date::str_alami> vs
 L<str_alami|Data::Sah::Coerce::date::str_alami> both parse natural language date
-string; there is little to none usefulness in using both; besides, both rules
-match all string and dies when failing to parse the string. So in C<str_natural>
-rule, you might find this metadata:
+string; there is usually little to none of usefulness in using both; besides,
+both rules match all string and dies when failing to parse the string. So in
+C<str_natural> rule, you'll find this metadata:
 
  precludes => [qr/\Astr_alami(_.+)?\z/]
 
-and in C<str_alami> rule you might find this metadata:
+and in C<str_alami> rule you'll find this metadata:
 
  precludes => [qr/\Astr_alami(_.+)?\z/, 'str_natural']
 
