@@ -1,7 +1,7 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2016-06-04'; # DATE
-our $VERSION = '0.015'; # VERSION
+our $DATE = '2016-06-12'; # DATE
+our $VERSION = '0.016'; # VERSION
 
 use 5.010001;
 use strict;
@@ -110,7 +110,7 @@ sub gen_coercer {
         print $jsh $src;
         close($jsh) or die "Can't write JS code to file $jsfn: $!";
 
-        my $out = IPC::System::Options::backtick($nodejs_path, $jsfn);
+        my $out = IPC::System::Options::readpipe($nodejs_path, $jsfn);
         $json->decode($out);
     };
 }
@@ -130,7 +130,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.015 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-06-04.
+This document describes version 0.016 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-06-12.
 
 =head1 SYNOPSIS
 
